<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Home',
'GOTO_CONTENT'			=> 'Goto content',
'GOTO_MENU'				=> 'Goto menu',
'COMMENTS_RSS_FEEDS'	=> 'Rss feeds comments',
'COMMENTS'				=> 'Comments',
'ARTICLES_RSS_FEEDS'	=> 'Rss feeds articles',
'ARTICLES'				=> 'Articles',

# sidebar.php
'CATEGORIES' 			=> 'Categories',
'LATEST_ARTICLES'		=> 'Latest articles',
'LATEST_COMMENTS'		=> 'Latest comments',
'ARCHIVES'				=> 'Archives',

# footer.php
'POWERED_BY'			=> 'Powered by',
'PLUXML_DESCRIPTION'	=> 'Blog or Cms without database',
'IN'					=> 'in',
'ADMINISTRATION'		=> 'Administration',
'GOTO_TOP'				=> 'Goto top',
'TOP'					=> 'Top',

# erreur.php
'ERROR'					=> 'Error found',
'BACKTO_HOME'			=> 'Goto home',

# common
'WRITTEN_BY'			=> 'Written by',
'CLASSIFIED_IN'			=> 'Classified in',
'TAGS'					=> 'Tags',

# commentaires.php
'SAID'					=> 'said',
'WRITE_A_COMMENT'		=> 'Write a comment',
'NAME'					=> 'Name',
'WEBSITE'				=> 'Site (optional)',
'EMAIL'					=> 'E-mail (optional)',
'COMMENT'				=> 'Comment',
'CLEAR'					=> 'Clear',
'SEND'					=> 'Send',
'COMMENTS_CLOSED'		=> 'Comments are closed',
'ANTISPAM_WARNING'		=> 'Anti-spam checking',

'REPLY'					=> 'Reply',
'REPLY_TO'				=> 'Reply to',
'CANCEL'				=> 'Cancel',

);

?>